'use strict';

var path = require('path');
var fs = require('fs');
var mkdirp = require('mkdirp');
var homeOrTmp = require('home-or-tmp');
var pathExists = require('path-exists');

var FILENAME = process.env.BABEL_CACHE_PATH || path.join(homeOrTmp, '.riq-babel-register.json');
var data = {};

/**
 * Write stringified cache to disk.
 */

var save = function save() {
  var serialised = {};
  try {
    serialised = JSON.stringify(data, null, '  ');
  } catch (err) {
    if (err.message === 'Invalid string length') {
      err.message = 'Cache too large so it\'s been cleared.';
      console.error(err.stack);
    } else {
      throw err;
    }
  }
  mkdirp.sync(path.dirname(FILENAME));
  fs.writeFileSync(FILENAME, serialised);
};

/**
 * Load cache from disk and parse.
 */

var load = function load() {
  if (process.env.BABEL_DISABLE_CACHE) return;

  process.on('exit', save);
  process.nextTick(save);

  if (!pathExists.sync(FILENAME)) return;

  try {
    data = JSON.parse(fs.readFileSync(FILENAME));
  } catch (err) {
    return;
  }
};

/**
 * Retrieve data from cache.
 */

function get() {
  return data;
}

exports.save = save;
exports.load = load;
exports.get = get;